#include "TM1636.h"
#include "functions.h"
#include "DHT.h"
#include <Bounce2.h>

//DHT11 Sensor am digitalen Pin D12
#define DHTPIN 12    

//definieren das der Sensortyp DHT11 ist
//Die Bibliothek DHT kann DHT22 und DHT21 Sensoren auslesen.
#define DHTTYPE DHT11 

DHT dht(DHTPIN, DHTTYPE);

//Pins für das Rich Shield
#define CLK 10
#define DATA 11

TM1636 tm1636(CLK, DATA);

#define LED_1 4 //LED1 rot
#define LED_2 5 //LED2 grün
#define LED_3 6 //LED3 blau

#define K1 9 //Taster K1 am digitalen Pin D9
#define K2 8 //Taster K2 am digitalen Pin D8

Bounce btnK1 = Bounce(K1, 50);
Bounce btnK2 = Bounce(K2, 50);

int index = 1;
double value;
int suffix;

void setup(){
  Serial.begin(9600);

  pinMode(K1, INPUT);
  pinMode(K2, INPUT);
  
  digitalWrite(K1, HIGH);  
  digitalWrite(K2, HIGH);  
  
  //Initialisieren der Anzeige.
  tm1636.init();
  dht.begin();
}

void loop(){  
 
  btnK1.update();
  btnK2.update();
 
  //Wenn der Taster K1 gedrückt wird,
  //dann soll der Index um eins erhöht erwerden.
  if(btnK1.fell()){ index = index+1; }
 
  //Wenn der Taster K2 gedrückt wird,
  //dann soll der Index um eins verringert werden.
  if(btnK2.fell()){ index = index-1; }

  if(index > 3 || index < 1){
     index = 1;
  }

  Serial.println(index);

  resetLeds();

  switch(index){
    case 1: displayHumidity(); break;
    case 2: displayTempC(); break;
    case 3: displayTempF(); break;
  }
}

void resetLeds(){
  digitalWrite(LED_1,LOW);
  digitalWrite(LED_2,LOW);
  digitalWrite(LED_3,LOW);
}

void displayHumidity(){
  double value = dht.readHumidity();
  Serial.print("Luftfeuchtigkeit: ");
  Serial.print(value);
  Serial.println("%");
  tm1636.display(getNumber(value));
  digitalWrite(LED_1,HIGH);
}

void displayTempC(){
  double value = dht.readTemperature();
  Serial.print("Temperatur: ");
  Serial.print(value);
  Serial.println("°C");
  tm1636.display(getNumber(value));
  digitalWrite(LED_2,HIGH);
}

void displayTempF(){
  double value = dht.readTemperature(true);
  Serial.print("Temperatur: ");
  Serial.print(value);
  Serial.println("°C");
  tm1636.display(getNumber(value));
  digitalWrite(LED_3,HIGH);
}
